@@ -183,7 +183,7 @@ class LibMarkdown(object):
             if len(i) != 0:
                 msg = i.replace('；',';')
                 msg = msg.replace('。',';')
-                msg = '。<br>'.join(msg.strip(';').split(';'))
+                msg = '<br>'.join(msg.strip(';').split(';'))
                 data += str(msg) + "|"
             else:
                 data += "&nbsp;" + "|"
