@@ -14,12 +14,21 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.2.8'
+__version__ = 'v1.2.9'
 
 class TranslateJson(object):
-    def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind):
+    def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
+            save_dir):
         self.js_file = js_file
-        self.link_path = link_path
+        if save_dir:
+            print('>>>>>>>>>>>>>>>>>')
+            dirname = os.path.dirname(self.js_file).strip('./')
+            print(dirname)
+            self.link_path = os.path.join(link_path, '_json_output', dirname)
+            print(self.link_path)
+            print('>>>>>>>>>>>>>>>>>')
+        else:
+            self.link_path = os.path.join(link_path, '_json_output')
         self.dir_type = dir_type
         self.output_md = output_md
         self.output_gitbook = output_gitbook
@@ -486,13 +495,13 @@ class TranslateJson(object):
     def check_file(self, file_name):
         if self.dir_type != "link":
             return
-        if os.path.exists(os.path.join(self.link_path, "_json_output", file_name)):
+        if os.path.exists(os.path.join(self.link_path, file_name)):
             add_cmd = "cat " + os.path.join(self.gitbookpath, file_name) + " >> " \
-                    + os.path.join(self.link_path, "_json_output", file_name)
+                    + os.path.join(self.link_path, file_name)
             os.system(add_cmd)
         else:
             mv_cmd = "mv " + os.path.join(self.gitbookpath, file_name) + " " \
-                    + os.path.join(self.link_path, "_json_output", file_name)
+                    + os.path.join(self.link_path, file_name)
             os.system(mv_cmd)
 
     def relist(self, in_list):
@@ -565,7 +574,7 @@ class TranslateJson(object):
                         fc.write("## 寄存器列表\n\n" + self.all_reg_data)
                 print("\n\tcreate " + self.gitbookpath +" success") 
             elif self.dir_type == "link":
-                self.gitbookpath = os.path.join(self.link_path, "_json_output/", file_msg)
+                self.gitbookpath = os.path.join(self.link_path, file_msg)
                 path_msg = "_json_output/" + str(file_msg)
                 if not os.path.exists(self.gitbookpath):
                     os.system("mkdir -p " + self.gitbookpath)
@@ -579,7 +588,7 @@ class TranslateJson(object):
                     reg_list_path = os.path.join(path_msg, "all_register.md") 
                     reg_detail_path = os.path.join(path_msg, "detail.md") 
                     fd.write('* [寄存器列表](' + reg_list_path + ')\n')
-                    fd.write('* [寄存器](' + reg_detail_path + ')\n')
+                    fd.write('* [寄存器详细说明](' + reg_detail_path + ')\n')
                     for i in self.js_dpath:
                         addr = self.get_addr(i)
                         self.path_addr_dict[i] = addr
@@ -656,16 +665,19 @@ def main():
     if len(sys.argv) <= 1:
             usage()
             sys.exit()
-    opts,args = getopt(sys.argv[1:],"f:l:gxhv")
+    opts,args = getopt(sys.argv[1:],"f:l:gxhdv")
     js_file = "demo.json"
     link_path = ''
     output_md = 1
     output_gitbook = 0
     output_xmind = 0
+    save_dir = 0
     dir_type = "alone"
     for k,v in opts:
         if k == "-f":
             js_file = v
+        if k == "-d":
+            save_dir = 1
         if k == "-l":
             link_path = v
             dir_type = "link"
@@ -683,7 +695,8 @@ def main():
             print(__version__)
             sys.exit()
     #print("opts:", opts, "args", args)
-    tj = TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook, output_xmind)
+    tj = TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
+            save_dir)
     tj.main()
 
 if __name__ == "__main__":
